@@ -66,81 +66,62 @@ ConvertFunction     gConvertTlutFunctions[ 8 ][ 4 ] =
 
 extern bool conkerSwapHack;
 
+// Super Mario 64, Zelda OOT
 void ConvertRGBA16(CTexture *pTexture, const TxtrInfo &tinfo)
 {
     DrawInfo dInfo;
 
     // Copy of the base pointer
-    uint16 * pSrc = (uint16*)(tinfo.pPhysicalAddress);
+    uint8 * pByteSrc = (uint8 *)(tinfo.pPhysicalAddress);
 
-    uint8 * pByteSrc = (uint8 *)pSrc;
     if (!pTexture->StartUpdate(&dInfo))
         return;
 
-    uint32 nFiddle;
+    // is only setted if the texture is swapped
+    uint32 nFiddle = 0x2;
 
-    if (tinfo.bSwapped)
+    for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
     {
-        for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
+        if (tinfo.bSwapped) // Super Smash Bros N64 logo
         {
-            if ((y&1) == 0)
-                nFiddle = 0x2;
+            if (y&1)
+                nFiddle = 0x2 | 0x4; // only odd lines are swapped
             else
-                nFiddle = 0x2 | 0x4;
-
-            // dwDst points to start of destination row
-            uint32 * dwDst = (uint32 *)((uint8 *)dInfo.lpSurface + y*dInfo.lPitch);
-
-            // DWordOffset points to the current dword we're looking at
-            // (process 2 pixels at a time). May be a problem if we don't start on even pixel
-            uint32 dwWordOffset = ((y+tinfo.TopToLoad) * tinfo.Pitch) + (tinfo.LeftToLoad * 2);
-
-            for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
-            {
-                uint16 w = *(uint16 *)&pByteSrc[dwWordOffset ^ nFiddle];
-
-                dwDst[x] = Convert555ToRGBA(w);
-                
-                // Increment word offset to point to the next two pixels
-                dwWordOffset += 2;
-            }
+                nFiddle = 0x2;
         }
-    }
-    else
-    {
-        for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
+
+        // dwDst points to start of destination row
+        uint32 * dwDst = (uint32 *)((uint8 *)dInfo.lpSurface + y*dInfo.lPitch);
+
+        // DWordOffset points to the current dword we're looking at
+        // (process 2 pixels at a time). May be a problem if we don't start on even pixel
+        uint32 dwWordOffset = ((y+tinfo.TopToLoad) * tinfo.Pitch) + (tinfo.LeftToLoad * 2);
+
+        for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
         {
-            // dwDst points to start of destination row
-            uint32 * dwDst = (uint32 *)((uint8 *)dInfo.lpSurface + y*dInfo.lPitch);
+            uint16 w = *(uint16 *)&pByteSrc[dwWordOffset ^ nFiddle];
 
-            // DWordOffset points to the current dword we're looking at
-            // (process 2 pixels at a time). May be a problem if we don't start on even pixel
-            uint32 dwWordOffset = ((y+tinfo.TopToLoad) * tinfo.Pitch) + (tinfo.LeftToLoad * 2);
+            dwDst[x] = Convert555ToRGBA(w);
 
-            for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
-            {
-                uint16 w = *(uint16 *)&pByteSrc[dwWordOffset ^ 0x2];
-
-                dwDst[x] = Convert555ToRGBA(w);
-                
-                // Increment word offset to point to the next two pixels
-                dwWordOffset += 2;
-            }
+            // Increment word offset to point to the next two pixels
+            dwWordOffset += 2;
         }
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
+// N64 32 bit textures are in R8G8B8A8 format. On little endian processors,
+// components are reverted during transfer to GPU. So RGBA is send as ABGR
+// which is not supported. We need to convert RGBA to ARGB (A8R8G8B8) because
+// ARGB will be BGRA on GPU.
 void ConvertRGBA32(CTexture *pTexture, const TxtrInfo &tinfo)
 {
     DrawInfo dInfo;
+
     if (!pTexture->StartUpdate(&dInfo))
         return;
 
-    uint32 * pSrc = (uint32*)(tinfo.pPhysicalAddress);
-
     if( options.bUseFullTMEM )
     {
         Tile &tile = gRDP.tiles[tinfo.tileNo];
@@ -172,66 +153,43 @@ void ConvertRGBA32(CTexture *pTexture, const TxtrInfo &tinfo)
     }
     else
     {
-        if (tinfo.bSwapped)
-        {
-            for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
-            {
-                if ((y%2) == 0)
-                {
-                    uint8 *pDst = (uint8 *)dInfo.lpSurface + y * dInfo.lPitch;
-                    uint8 *pS = (uint8 *)pSrc + (y+tinfo.TopToLoad) * tinfo.Pitch + (tinfo.LeftToLoad*4);
+        // Copy of the base pointer
+        uint8 * pByteSrc = (uint8 *)tinfo.pPhysicalAddress;
 
-                    for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
-                    {
-                        pDst[0] = pS[1];    // Blue
-                        pDst[1] = pS[2];    // Green
-                        pDst[2] = pS[3];    // Red
-                        pDst[3] = pS[0];    // Alpha
-                        pS+=4;
-                        pDst+=4;
-                    }
-                }
+        // is only setted if the texture is swapped
+        uint32 nFiddle = 0x0;
+
+        for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
+        {
+            // non swapped: Banjo Tooie Title screen
+            // swapped: Super Smash Bros N64 logo
+            if (tinfo.bSwapped)
+            {
+                if (y&1)
+                    nFiddle = 0x8; // only odd lines are swapped
                 else
-                {
-                    uint32 *pDst = (uint32 *)((uint8 *)dInfo.lpSurface + y * dInfo.lPitch);
-                    uint8 *pS = (uint8 *)pSrc;
-                    int n;
-
-                    n = (y+tinfo.TopToLoad) * tinfo.Pitch + (tinfo.LeftToLoad*4);
-                    for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
-                    {
-                        *pDst++ = COLOR_RGBA(pS[(n+3)^0x8],
-                            pS[(n+2)^0x8],
-                            pS[(n+1)^0x8],
-                            pS[(n+0)^0x8]);
-
-                        n += 4;
-                    }
-                }
+                    nFiddle = 0x0;
             }
-        }
-        else
-        {
-            for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
-            {
-                uint8 *pDst = (uint8 *)dInfo.lpSurface + y * dInfo.lPitch;
-                uint8 *pS = (uint8 *)pSrc + (y+tinfo.TopToLoad) * tinfo.Pitch + (tinfo.LeftToLoad*4);
 
-                for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
-                {
-                    pDst[0] = pS[1];    // Blue
-                    pDst[1] = pS[2];    // Green
-                    pDst[2] = pS[3];    // Red
-                    pDst[3] = pS[0];    // Alpha
-                    pS+=4;
-                    pDst+=4;
-                }
+            // dwDst points to start of destination row
+            uint32 * dwDst = (uint32 *)((uint8 *)dInfo.lpSurface + y*dInfo.lPitch);
+
+            // offset in byte to the start of the current row
+            uint32 byteOffset = ((y+tinfo.TopToLoad) * tinfo.Pitch) + (tinfo.LeftToLoad * 4);
+
+            for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
+            {
+                uint32 dw = *(uint32 *)&pByteSrc[byteOffset^nFiddle];
+
+                dwDst[x] = RGBA_TO_ARGB(dw);
+
+                // move to the next pixel
+                byteOffset += 4;
             }
         }
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 // E.g. Dear Mario text
@@ -335,7 +293,6 @@ void ConvertIA4(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 
 }
 
@@ -384,7 +341,7 @@ void ConvertIA8(CTexture *pTexture, const TxtrInfo &tinfo)
     }
     else
     {
-        register const uint8* FourToEightArray = &FourToEight[0];
+        const uint8* FourToEightArray = &FourToEight[0];
         for (uint32 y = 0; y < tinfo.HeightToLoad; y++)
         {
             uint8 *pDst = (uint8 *)dInfo.lpSurface + y * dInfo.lPitch;
@@ -394,7 +351,7 @@ void ConvertIA8(CTexture *pTexture, const TxtrInfo &tinfo)
 
             for (uint32 x = 0; x < tinfo.WidthToLoad; x++)
             {
-                register uint8 b = pSrc[(dwByteOffset++) ^ 0x3];
+                uint8 b = pSrc[(dwByteOffset++) ^ 0x3];
                 uint8 I = *(FourToEightArray+(b>>4));
 
                 *pDst++ = I;
@@ -406,7 +363,6 @@ void ConvertIA8(CTexture *pTexture, const TxtrInfo &tinfo)
     }   
     
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 
 }
 
@@ -474,7 +430,6 @@ void ConvertIA16(CTexture *pTexture, const TxtrInfo &tinfo)
 
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 
@@ -590,7 +545,6 @@ void ConvertI4(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 // Used by MarioKart
@@ -652,7 +606,6 @@ void ConvertI8(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 
 }
 
@@ -789,7 +742,6 @@ void ConvertCI4_RGBA16(CTexture *pTexture, const TxtrInfo &tinfo)
         }
     }
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 // Used by Starfox intro
@@ -896,7 +848,6 @@ void ConvertCI4_IA16(CTexture *pTexture, const TxtrInfo &tinfo)
         }
     }
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 
@@ -970,7 +921,6 @@ void ConvertCI8_RGBA16(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 
 }
 
@@ -1044,7 +994,6 @@ void ConvertCI8_IA16(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 void ConvertYUV(CTexture *pTexture, const TxtrInfo &tinfo)
@@ -1148,7 +1097,6 @@ void ConvertYUV(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 uint32 ConvertYUV16ToR8G8B8(int Y, int U, int V)
@@ -1299,7 +1247,6 @@ void Convert4b(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 void Convert8b(CTexture *pTexture, const TxtrInfo &tinfo)
@@ -1400,7 +1347,6 @@ void Convert8b(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
 
@@ -1470,6 +1416,5 @@ void Convert16b(CTexture *pTexture, const TxtrInfo &tinfo)
     }
 
     pTexture->EndUpdate(&dInfo);
-    pTexture->SetOthersVariables();
 }
 
