@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 void RSP_GBI2_Vtx(Gfx *gfx)
 {
     uint32 addr = RSPSegmentAddr((gfx->gbi2vtx.addr));
-    int vend    = gfx->gbi2vtx.vend/2;
+    int vend    = gfx->gbi2vtx.vend;
     int n       = gfx->gbi2vtx.n;
     int v0      = vend - n;
 
@@ -261,7 +261,6 @@ void RSP_GBI2_Tri1(Gfx *gfx)
                         InitVertexTextureConstants();
                     }
 
-                    CRender::g_pRender->SetCombinerAndBlender();
                     bTrisAdded = true;
                 }
                 PrepareTriangle(dwV0, dwV1, dwV2);
@@ -280,6 +279,7 @@ void RSP_GBI2_Tri1(Gfx *gfx)
 
         if (bTrisAdded) 
         {
+            CRender::g_pRender->SetCombinerAndBlender();
             CRender::g_pRender->DrawTriangles();
         }
 
@@ -329,7 +329,6 @@ void RSP_GBI2_Tri2(Gfx *gfx)
                         InitVertexTextureConstants();
                     }
 
-                    CRender::g_pRender->SetCombinerAndBlender();
                     bTrisAdded = true;
                 }
 
@@ -348,7 +347,6 @@ void RSP_GBI2_Tri2(Gfx *gfx)
                         InitVertexTextureConstants();
                     }
 
-                    CRender::g_pRender->SetCombinerAndBlender();
                     bTrisAdded = true;
                 }
 
@@ -369,6 +367,7 @@ void RSP_GBI2_Tri2(Gfx *gfx)
 
         if (bTrisAdded) 
         {
+            CRender::g_pRender->SetCombinerAndBlender();
             CRender::g_pRender->DrawTriangles();
         }
 
@@ -414,11 +413,6 @@ void RSP_GBI2_Line3D(Gfx *gfx)
                     InitVertexTextureConstants();
                 }
 
-                if( !bTrisAdded )
-                {
-                    CRender::g_pRender->SetCombinerAndBlender();
-                }
-
                 bTrisAdded = true;
                 PrepareTriangle(dwV0, dwV1, dwV2);
             }
@@ -433,11 +427,6 @@ void RSP_GBI2_Line3D(Gfx *gfx)
                     InitVertexTextureConstants();
                 }
 
-                if( !bTrisAdded )
-                {
-                    CRender::g_pRender->SetCombinerAndBlender();
-                }
-
                 bTrisAdded = true;
                 PrepareTriangle(dwV3, dwV4, dwV5);
             }
@@ -456,6 +445,7 @@ void RSP_GBI2_Line3D(Gfx *gfx)
 
         if (bTrisAdded) 
         {
+            CRender::g_pRender->SetCombinerAndBlender();
             CRender::g_pRender->DrawTriangles();
         }
 
