@@ -21,6 +21,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef __RICE_RDP_GFX_H__
 #define __RICE_RDP_GFX_H__
 
+#if defined(__GNUC__)
+#define ATTR_FMT(fmtpos, attrpos) __attribute__ ((format (printf, fmtpos, attrpos)))
+#else
+#define ATTR_FMT(fmtpos, attrpos)
+#endif
+
 #include "typedefs.h"
 
 #define RSP_SPNOOP              0   // handle 0 gracefully 
@@ -176,6 +182,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define RDP_TFILTER_AVERAGE     (3 << RSP_SETOTHERMODE_SHIFT_TEXTFILT)
 #define RDP_TFILTER_BILERP      (2 << RSP_SETOTHERMODE_SHIFT_TEXTFILT)
 
+/* G_SETOTHERMODE_H gSetCombineKey */
+#define RDP_COMBKEY_NONE   (0 << RSP_SETOTHERMODE_SHIFT_COMBKEY)
+#define RDP_COMBKEY_KEY    (1 << RSP_SETOTHERMODE_SHIFT_COMBKEY)
+
 // RSP_SETOTHERMODE_L gSetAlphaCompare 
 #define RDP_ALPHA_COMPARE_NONE          (0 << RSP_SETOTHERMODE_SHIFT_ALPHACOMPARE)
 #define RDP_ALPHA_COMPARE_THRESHOLD     (1 << RSP_SETOTHERMODE_SHIFT_ALPHACOMPARE)
@@ -468,16 +478,17 @@ typedef struct{
 } Sprite2DInfo;
 
 
+// Blender equation: (A*P+B*M)/(A+B)
 typedef struct
 {
-    unsigned int    c2_m2b:2;
-    unsigned int    c1_m2b:2;
-    unsigned int    c2_m2a:2;
-    unsigned int    c1_m2a:2;
-    unsigned int    c2_m1b:2;
-    unsigned int    c1_m1b:2;
-    unsigned int    c2_m1a:2;
-    unsigned int    c1_m1a:2;
+    unsigned int    c2_m2b:2; // M (cycle 2)
+    unsigned int    c1_m2b:2; // M (cycle 1)
+    unsigned int    c2_m2a:2; // B (cycle 2)
+    unsigned int    c1_m2a:2; // B (cycle 1)
+    unsigned int    c2_m1b:2; // P (cycle 2)
+    unsigned int    c1_m1b:2; // P (cycle 1)
+    unsigned int    c2_m1a:2; // A (cycle 2)
+    unsigned int    c1_m1a:2; // A (cycle 1)
 } RDP_BlenderSetting;
 
 typedef struct
@@ -505,7 +516,7 @@ typedef struct
             unsigned int        force_bl : 1;               // 14
             unsigned int        tex_edge : 1;               // 15 - Not used
 
-            unsigned int        blender : 16;               // 16..31
+            unsigned int        blender : 16;               // 16..31 (Defined in RDP_BlenderSetting)
 
             // High bits
             unsigned int        blend_mask : 4;             // 0..3 - not supported
@@ -623,7 +634,7 @@ uint32 DLParser_CheckUcode(uint32 ucStart, uint32 ucDStart, uint32 ucSize, uint3
 bool IsUsedAsDI(uint32 addr);
 
 #if defined(DEBUGGER)
-  void __cdecl LOG_UCODE(const char* szFormat, ...);
+  void __cdecl LOG_UCODE(const char* szFormat, ...) ATTR_FMT(1,2);
 #else
   inline void LOG_UCODE(...) {}
 #endif
