@@ -87,7 +87,7 @@ void RSP_S2DEX_OBJ_RECTANGLE(Gfx *gfx)
             debuggerPause = true;
             TRACE3("Paused at RSP_S2DEX_OBJ_RECTANGLE\nptr=%08X, img=%08X, Tmem=%08X",
                 dwAddr,objtx.txtr.block.image, ptr->imageAdrs);
-            CGraphicsContext::g_pGraphicsContext->UpdateFrame();
+            CGraphicsContext::Get()->UpdateFrame();
         }
     }
 #endif
@@ -103,8 +103,6 @@ void RSP_S2DEX_OBJ_SPRITE(Gfx *gfx)
     status.bAllowLoadFromTMEM = false;  // Because we need to use TLUT loaded by ObjTlut cmd
     PrepareTextures();
     status.bAllowLoadFromTMEM = true;
-    
-    //CRender::g_pRender->SetCombinerAndBlender();
 
     uObjTxSprite drawinfo;
     memcpy( &(drawinfo.sprite), info, sizeof(uObjSprite));
@@ -126,7 +124,7 @@ void RSP_S2DEX_OBJ_SPRITE(Gfx *gfx)
         eventToPause = false;
         debuggerPause = true;
         TRACE0("Paused at RSP_S2DEX_OBJ_SPRITE");
-        CGraphicsContext::g_pGraphicsContext->UpdateFrame();
+        CGraphicsContext::Get()->UpdateFrame();
     }
 #endif
 }
