@@ -26,7 +26,10 @@
 */
 
 #include <stdlib.h>
+
 #include "BMGUtils.h"
+#include "../osal_preproc.h"
+#include "BMGImage.h"
 
 #ifndef _WIN32
 #include <string.h>
