@@ -1,6 +1,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *   Mupen64plus - osal_opengl.h                                           *
- *   Mupen64Plus homepage: http://code.google.com/p/mupen64plus/           *
+ *   Mupen64Plus homepage: https://mupen64plus.org/                        *
  *   Copyright (C) 2013 Richard Goedeken                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,20 +24,14 @@
 
 #include <SDL_config.h>
 
-#ifndef USE_GLES
+// Vertex shader params
+#define VS_POSITION             0
+#define VS_COLOR                1
+#define VS_TEXCOORD0            2
+#define VS_TEXCOORD1            3
+#define VS_FOG                  4
 
-#ifndef SDL_VIDEO_OPENGL
-#error SDL is not build with OpenGL support. Try USE_GLES=1
-#endif
-
-#include <SDL_opengl.h>
-
-#define GLSL_VERSION "120"
-
-// Extension names
-#define OSAL_GL_ARB_TEXTURE_ENV_ADD         "GL_ARB_texture_env_add"
-
-#else // !USE_GLES
+#ifdef USE_GLES
 
 #ifndef SDL_VIDEO_OPENGL_ES2
 #error SDL is not build with OpenGL ES2 support. Try USE_GLES=0
@@ -47,39 +41,49 @@
 
 #define GLSL_VERSION "100"
 
-// Extension names
-#define OSAL_GL_ARB_TEXTURE_ENV_ADD         "GL_texture_env_add"
-
-// Vertex shader params
-#define VS_POSITION                         0
-#define VS_COLOR                            1
-#define VS_TEXCOORD0                        2
-#define VS_TEXCOORD1                        3
-#define VS_FOG                              4
+// SDL_opengles2.h define GL_APIENTRYP instead of APIENTRYP
+#define APIENTRYP GL_APIENTRYP
 
 // Constant substitutions
-#define GL_CLAMP                            GL_CLAMP_TO_EDGE
-#define GL_MAX_TEXTURE_UNITS                GL_MAX_TEXTURE_IMAGE_UNITS
-#define GL_MIRRORED_REPEAT_ARB              GL_MIRRORED_REPEAT
+#define GL_CLAMP                GL_CLAMP_TO_EDGE
+#define GL_MIRRORED_REPEAT_ARB  GL_MIRRORED_REPEAT
 
-#define GL_ADD                              0x0104
-#define GL_MODULATE                         0x2100
-#define GL_INTERPOLATE                      0x8575
-#define GL_CONSTANT                         0x8576
-#define GL_PREVIOUS                         0x8578
+#define GL_ADD                  0x0104
+#define GL_MODULATE             0x2100
+#define GL_INTERPOLATE          0x8575
+#define GL_CONSTANT             0x8576
+#define GL_PREVIOUS             0x8578
 
 // Function substitutions
-#define glClearDepth                        glClearDepthf
-#define pglActiveTexture                    glActiveTexture
+#define glClearDepth            glClearDepthf
+#define glDepthRange            glDepthRangef
 
 // No-op substitutions (unavailable in GLES2)
 #define glLoadIdentity()
-#define glMatrixMode(x)
-#define glOrtho(a,b,c,d,e,f)
 #define glReadBuffer(x)
 #define glTexEnvi(x,y,z)
-#define glTexEnvfv(x,y,z)
-#define glTexCoord2f(u,v)
+
+#else // !USE_GLES
+
+#ifndef SDL_VIDEO_OPENGL
+#error SDL is not build with OpenGL support. Try USE_GLES=1
+#endif
+
+#if defined(__APPLE__)
+    #include <OpenGL/gl.h>
+    #include <OpenGL/glext.h>
+    #define APIENTRY
+#endif
+
+#if defined(WIN32)
+#include <windows.h>
+#include <GL/gl.h>
+#include <GL/glext.h>
+#else
+#include <SDL_opengl.h>
+#endif
+
+#define GLSL_VERSION "120"
 
 #endif // !USE_GLES
 
